**	THIS FILE ANALYZES THE AGENT POPULATION

*****************************************************************************
**	DEFINE THE SIMULATION RUN:

	** 1. SET THE MAIN DIRECTORY (THE VERSION FOLDER)
		global DIR "D:\MPMAS\Ghana_casestudy\TONO_10\"

	** 2. DEFINE THE PREFIX OF THE OUTPUT FILES (SIMULATION RUN):
		global RUN "BSL"

	** 3. DEFINE THE NUMBER OF CLUSTERS IN THE POPULATION:
		global CLUSTERS "4"

*****************************************************************************

** 	IMPORT THE .LT2 FILES
**	quietly run stata\do\RUN_AGENTS.do

*****************************************************************************

** 	CONDUCT ANALYSES
	cd $DIR

** 	OPEN THE FILE
	use stata\temp\BSL_Agents.dta, clear

** 	AGENT LAND DISTRIBUTION



**	AGENT HOUSEHOLD COMPOSITION (POPULATION PYRAMID)
	save stata/temp/temp.dta, replace


	keep run seed aid vid v9-v42

	reshape long v, i(aid vid) j(num)
	ren v fem

	sort run seed aid num
	bysort seed aid : gen age = _n
	* Check here if num and age are both sorted
	drop num
	sort run seed aid age
	save stata/temp/female.dta, replace

	use stata/temp/temp.dta, clear
	keep run seed aid vid v43-v76
	reshape long v, i(aid vid) j(num)
	ren v mal 
	sort run seed aid num
	bysort seed aid : gen age = _n
	drop num
	move age mal
	sort run seed aid age
	merge run seed aid age using stata/temp/female.dta
	drop _m
	erase stata/temp/female.dta

	** 	COLLAPSE TO 34 AGE CATEGORIES
		collapse (sum) mal fem , by(run seed age)	

	** 	REDUCE TO 17 AGE CATEGORIES
		g cat = .
		local i = 1
		local j = 1
		foreach n of numlist 1(1)34 {
			replace cat = `i' if age == `n'
			local j = `j' + 1
			if (`j'==3) {
				local i = `i'+1
				local j = 1
				}
			}
		collapse (sum) mal fem , by(run seed cat)	
	
	**	GIVE LABELS TO CATEGORIES
		local l = 0
		local u = 5
		foreach n of numlist 1(1)17 {
			label define labage `n' "`l' to `u'", add
			local l = `l' + 6
			local u = `u' + 6
			}
		label define labage 17 "96 to 100", modify
		label values cat labage
	
	** 	EACH CATEGORY AS A % OF TOTAL POPULATION
		bysort run seed: egen mt = sum(mal) 
		bysort run seed: egen ft = sum(fem)
		g p_mal = mal / mt*100
		g p_fem = fem / ft*100
	
		replace p_mal = -p_mal 


	** 	GRAPHS
		save stata/temp/temp.dta, replace

		foreach r of global RUN {
			use stata/temp/temp.dta, clear
			drop if run != "`r'"
		
			graph twoway (bar p_mal cat, bc(forest_green) horizontal) ||  (bar  p_fem cat, bc(lavender) horizontal) , ylabel(1(1)17, angle(horizontal) valuelabel labsize(medsmall)) xtitle(% of population, size(medlarge) margin(small)) ytitle("") xlabel(-20 "20"-15 "15" -10 "10" -5 "5" 0 5 10 15 20, labsize(medlarge)) legend(label(1 Males) label(2 Females)) legend(width(80)) ysize(20) xsize(20) graphregion(fc(white) margin(t-3 r+ 0 b-2)) plotregion(margin(zero) lc(black)) title(Agent population, size(medium) margin(medium)) 
		
graph export stata/results/Pyramid17_Scen`r'.tif, replace
			}

** 	ERASE TEMPORARY FILES
	erase stata/temp/temp.dta
	label drop labage

