** 	THIS FILE COMPARES OBSERVED WITH PREDICTED LAND USE
** 	marea = model area ("predicted")
**	sarea = survey area ("observed")

**	NEDUMARAN
**	30 JULY. 2009

	clear
	set mem 200m

** 	CHANGE THE DIRECTORY
	cd $DIR

**	READ IN GROUP ID DATA AND SAVE IN STATA FORMAT

		insheet using model_gid.txt
		rename distid DistID
		rename clustid clustID
		rename aid  aID
		rename gid  gID

		sort  aID
		save model_gid, replace

	** HOUSEHOLD ID
		clear
		insheet using model_hid.txt
		rename distid DistID
		rename clustid clustID
		rename aid  aID
		rename hhid  hhID

		sort  aID
		save model_hid, replace


** 	OPEN SOLUTION.DTA
	use B_A_Solution, clear

** 	VALIDATE ONLY THE BASELINE SCENARIO
	keep if run == "B_A"

** 	KEEP ONLY THE FIRST 3 YEARS
	
	drop if period==1
    

*************************************************************************************

** 	GROUP THE CROPS

**	RICE AREA
	egen marea_irice = rowtotal(grow_irice_*)
	egen marea_rfrice = rowtotal(grow_rfrice_*)
	egen marea_sprice = rowtotal(grow_sprice_*)
**	TOTAL RICE AREA

	egen marea_rice = rowtotal(grow_irice_* grow_rfrice_* grow_sprice_*)	


**	RAINFED CROPS
	egen marea_rfmaize = rowtotal(grow_rfmaize)
	egen area_mil = rowtotal( grow_cp_mil_1 grow_cp_mil_2 grow_cp_mil_gc_1 grow_cp_mil_gc_2 grow_cp_gc_mil_1 grow_cp_gc_mil_2 grow_millet_wocash) /*Millet and guinea corn*/
	egen area_mil_bean = rowtotal(grow_b_mb_* grow_cp_mil_b_* grow_cp_gmil_b_* grow_cp_gmil2_b_* grow_b_mb_wocash)/*millet and beans*/
	egen area_gnut_bean = rowtotal(grow_b_gb grow_b_gb_m grow_b_gb_fm grow_cp_gnut_b grow_cp_gnut_b_m grow_cp_gnut_b_fm grow_cp_gnut_bb)/*groundnut and beans*/
	egen area_gnut = rowtotal(grow_b_gnut_* grow_cp_gnut) /*Groundnut sole crop*/

**	IRRIGATED CROP AREA
	egen marea_tomato = rowtotal(grow_tom_*)
	egen marea_onion = rowtotal(grow_onion_*)
	egen marea_irmaize = rowtotal(grow_feb_irrimaize_* grow_mar_irrimaize_* grow_aprl_irrimaize_*)

**	ANALYZE THE INTERCROPS

	g ic_mb = area_mil_bean*0.9
	g ic_bm = area_mil_bean*0.1

	g ic_gb = area_gnut_bean*0.9
	g ic_bg = area_gnut_bean*0.1

	g marea_millet = area_mil+ ic_mb
	g marea_beans = ic_bm+ic_bg
	g marea_groundnut = area_gnut+ic_gb


	quietly gen  D_2 = 2 if fstID <1000000
	quietly gen  D_1 = 1 if fstID >1000000
	egen DistID= rsum(D_*)


	keep marea_*  aID clustID period DistID
	order period DistID clustID aID marea_*

**	MERGE WITH GROUP ID
	sort aID
	merge aID using model_gid
	 drop _merge

**	MERGE WITH HOUSEHOLD ID
	sort aID
	merge aID using model_hid
	 drop _merge


** 	CALCULATE THE AVERAGE OVER THE PERIODS
	collapse (mean) marea_* ,by (DistID clustID hhID  aID) fast
	egen area_tot =rowtotal(marea_*)
	drop  if area_tot==0
	drop area_tot

** 	DROP THE AGENTS NOT SELECTED IN RANDOM
	drop if hhID==0
	gen hID=_n
	drop hhID
	gen hhID=hID
	drop hID
	drop if hhID==92

** 	RESHAPE TO CROPS
	reshape long marea_ ,i(DistID clustID hhID aID) j(crop) string

**	CALCULATE THE AREA FOR EACH LOCATION
	/*
	** BY DISTRICT
	foreach d of numlist 1(1)2 {
			quietly gen  marea_d`d' = marea_ if DistID == `d'
			}

	** BY CLUSTER
	foreach c of numlist 0(1)3 {
			quietly gen  marea_c`c' = marea_ if clustID == `c'
			}
	
	** BY GROUP
		foreach g of numlist 0(1)28 {
			quietly gen  marea_g`g' = marea_ if gID == `g'
			}
*/
	** BY HOUSEHOLD
	foreach h of numlist 1(1)91 {
			quietly gen  marea_h`h' = marea_ if hhID == `h'
			}

	
** 	COLLAPSE TO THE CROP LEVEL
	collapse (sum) marea_*, by(crop) fast

**	RENAME CROPS
	g str18 cropname = "."
	replace cropname = "Rice" 			if crop == "rice"
	replace cropname = "Irrigated Rice" 	if crop == "irice"
	replace cropname = "Rainfed Rice" 		if crop == "rfrice"
	replace cropname = "Beans" 			if crop == "beans"
	replace cropname = "Groundnut" 		if crop == "groundnut"
	replace cropname = "Irrigated Maize" 		if crop == "irmaize"
	replace cropname = "Onion" 		if crop == "onion"
	replace cropname = "Tomato" 		if crop == "tomato"
	replace cropname = "Sup Irrigated Rice" 		if crop == "sprice"
	replace cropname = "Rainfed Maize" 		if crop == "rfmaize"
	
	replace cropname = "Millet" 		if crop == "millet"
	replace cropname = "Beans" 		if crop == "beans"


** 	MERGE WITH THE AREAS FROM THE SURVEY
	sort  crop
	merge crop using survey_croparea

	drop _m 

   	drop if sarea_ ==.
	drop if marea_ ==.

	rename marea_ marea_cat
	rename sarea_ sarea_cat
	


**	CALCULATE PERCENTAGES 
	
	** By location
	local type  "s m"
	
	
	foreach t of local type {
	** Location level
		local level "cat  "
		foreach l of local level {
			quietly egen t_`t'area_`l' = total(`t'area_`l') if marea_`l' != .
			quietly gen p_`t'area_`l' = `t'area_`l' / t_`t'area_`l' * 100 if marea_`l' != .
			drop t_`t'area_`l' 
			
			}


/*
	** Cluster level
		foreach d of numlist 0(1)3 {
		  quietly egen t_`t'area_c`d' = total(`t'area_c`d') if marea_c`d' != .
		  quietly gen p_`t'area_c`d' = `t'area_c`d' / t_`t'area_c`d' * 100 if marea_c`d' != .
		  drop t_`t'area_c`d' `t'area_c`d'
		  

			}
	** Group level
		foreach g of numlist 0(1)28 {
		  quietly egen t_`t'area_g`g' = total(`t'area_g`g') if marea_g`g' != .
		  quietly gen p_`t'area_g`g' = `t'area_g`g' / t_`t'area_g`g' * 100 if marea_g`g' != .
		  drop t_`t'area_g`g' `t'area_g`g'
			

			}
*/
	** Household level
		foreach h of numlist 1(1)91 {
		  quietly egen t_`t'area_h`h' = total(`t'area_h`h') if marea_h`h' != .
		  quietly gen p_`t'area_h`h' = `t'area_h`h' / t_`t'area_h`h' * 100 if marea_h`h' != .
		  drop t_`t'area_h`h' `t'area_h`h'
		
			}
		   }

** 	SAVE THE DATA SET
	save validation.dta, replace

**	VALIDATION 

	use validation.dta, clear
	
	local v = 0
	local s = 1
	
	** BY DISTRICT

	local level "cat "
	quietly foreach l of local level {
		local v = `v' + 1
		g srt2_`l' = `v'

		if ("`l'" == "cat") g srt1_`l' = 0
		if ("`l'" != "cat") g srt1_`l' = `s' 
		regress p_marea_`l' p_sarea_`l' if (p_marea_`l' >0 | p_sarea_`l' >0), r noc
		g r2_`l' 	= e(r2) 
		g b_`l'	= _b[p_sarea_`l']    
		g se_`l'	= _se[p_sarea_`l']
		g t_`l'	= b_`l'/ se_`l'
		replace t_`l' = 0 if se_`l' == 0
		g df_`l'    = e(df_r)
		g sig_`l'   = tprob(df_`l', t_`l')
		}
/*
	** BY CLUSTER
	local s = `s' + 1
	local v = 0
	quietly foreach l of numlist 0(1)3 {
		local v = `v' + 1

		** Check if there are enough observations
		sum p_marea_c`l' if p_marea_c`l' > 0
		local mo = r(N)
		sum p_sarea_c`l' if p_sarea_c`l' > 0
		local so = r(N)

		if `mo' > 1 & `so' > 1 {
			g srt2_c`l' = `v' 
			g srt1_c`l' = `s' 

			regress p_marea_c`l' p_sarea_c`l' if (p_marea_c`l' >0 | p_sarea_c`l' >0), r noc
			g r2_c`l' 	= e(r2) 
			g b_c`l'	= _b[p_sarea_c`l']    
			g se_c`l'	= _se[p_sarea_c`l']
			g t_c`l'	= b_c`l'/ se_c`l'
			replace t_c`l' = 0 if se_c`l' == 0
			g df_c`l'   = e(df_r)
			g sig_c`l'  = tprob(df_c`l', t_c`l')
			}
		}

	** BY GROUP
	local s = `s' + 1
	local v = 0
	quietly foreach l of numlist 0(1)28 {
		local v = `v' + 1

		** Check if there are enough observations
		sum p_marea_g`l' if p_marea_g`l' > 0
		local mo = r(N)
		sum p_sarea_g`l' if p_sarea_g`l' > 0
		local so = r(N)

		if `mo' > 1 & `so' > 1 {
			g srt2_g`l' = `v' 
			g srt1_g`l' = `s' 

			regress p_marea_g`l' p_sarea_g`l' if (p_marea_g`l' >0 | p_sarea_g`l' >0), r noc
			g r2_g`l' 	= e(r2) 
			g b_g`l'	= _b[p_sarea_g`l']    
			g se_g`l'	= _se[p_sarea_g`l']
			g t_g`l'	= b_g`l'/ se_g`l'
			replace t_g`l' = 0 if se_g`l' == 0
			g df_g`l'   = e(df_r)
			g sig_g`l'  = tprob(df_g`l', t_g`l')
			}
		}
*/
	** BY HOUSEHOLD LEVEL
	local s = `s' + 1
	local v = 0
	quietly foreach l of numlist 1(1)91 {
		local v = `v' + 1

		** Check if there are enough observations
		sum p_marea_h`l' if p_marea_h`l' > 0
		local mo = r(N)
		sum p_sarea_h`l' if p_sarea_h`l' > 0
		local so = r(N)

		if `mo' > 1 & `so' > 1 {
			g srt2_h`l' = `v' 
			g srt1_h`l' = `s' 

			regress p_marea_h`l' p_sarea_h`l' if (p_marea_h`l' >0 | p_sarea_h`l' >0), r noc
			g r2_h`l' 	= e(r2) 
			g b_h`l'	= _b[p_sarea_h`l']    
			g se_h`l'	= _se[p_sarea_h`l']
			g t_h`l'	= b_h`l'/ se_h`l'
			replace t_h`l' = 0 if se_h`l' == 0
			g df_h`l'   = e(df_r)
			g sig_h`l'  = tprob(df_h`l', t_h`l')
			}
		}


	sort crop
	drop *area* crop cropname
	keep in 1
	gen one = 1
	quietly reshape long r2_ b_ se_ t_ df_ sig_ srt1_ srt2_, i(one) j(level) string
	sort srt1 srt2
	drop one

	order level b se t sig df r2
	

**	META STATISTICS
	collapse (mean) b se sig r2 df (count) n=b, by(srt1) fast
	sort srt1	
	
	gen str10 location	= "Catchment" 		if srt1 == 0
	

	replace location 		= "Household" 		if srt1 == 2

	order srt1 location

	list
	table location, c(mean b mean se mean sig mean r2 mean df)
	table location, c(mean n )
gg

**	CALCULATE PERCENTAGES 

	local type  "s m"
	
		foreach t of local type {
			quietly egen t_`t'area = total(`t'area) if marea != .
			quietly gen p_`t'area = `t'area / t_`t'area * 100 if marea != .
			drop t_`t'area 
			}


	regress p_marea p_sarea, r noc
	g b  = _b[p_sarea]    
	g se = _se[p_sarea]
	g t = b / se
	g df = e(df_r)
	g sig = tprob(df, t)


** SCATTER: OBSERVED VS. SIMULATED LAND USE (%)
	graph twoway scatter  p_marea p_sarea, msize(medium) mlabel(cropname) ms(square) mlc(black) mc(none) || function y = _b[p_sarea]*x, range(0 40)   ylabel(0(20)60, angle(horizontal) labsize(medium) grid glc(black) glw(*0.5) gmax) xlabel(0(20)80, labsize(medium) grid glc(black) glw(*0.5) gmax) xtitle("Observed values (%)", size(medlarge) margin(medium)) ytitle("Simulated values (%)", size(medlarge) margin(medium)) legend(off) plotregion(fc(white) lc(black)) graphregion(fc(white) margin(b-3 l-5)) ysize(20) xsize(20) title("Observed vs. simulated land use" "as a % of the total area under crops", size(medlarge)) 
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\Stata\results\Valarea_per_BSL.tif", as(tif) replace



** BAR: OBSERVED AND SIMULATED LAND USE (HA)
	**graph hbar (asis) sarea marea , over(cropname, gap(*0.6) sort(sarea_ws) ) bar(1, fcolor(gs7) lcolor(gs7)) bar(2, fcolor(black) lcolor(black))  plotregion(lc(black)) graphregion(fc(white) margin(b-5 l+0)) ytitle("Crop area (ha)", margin(small)) bargap(0) outergap(*0) ylabel(0(50)350 , glc(black*0.5) glw(*0.5)) ytick(0(25)350) ysize(20) xsize(17) legend(label(1 "Observed") label(2 "Simulated") ring(0) pos(2) col(1) size(medsmall)  nobox symx(*0.5) region(lc(white)))
	**graph export "D:\MPMAS\Ghana_casestudy\TONO_01\stata/results/ValArea_barha_BSL.tif", as(tif) replace

** BAR: OBSERVED AND SIMULATED LAND USE (%)
	**graph hbar (asis) p_marea p_sarea , over(cropname, gap(*0.6) sort(sarea_ws) ) bar(1, fcolor(gs7) lcolor(gs7))  bar(2, fcolor(black) lcolor(black)) plotregion(lc(black)) graphregion(fc(white) margin(b-5 l+0)) yscale(range(0 30)) ytitle("Crop area (%)", margin(small)) bargap(0) outergap(*0.5) ylabel(0(5)60, glc(black*0.5) glw(*0.5) gmax gmin) ymtick(0(1)60) ysize(20) xsize(17) legend(label(1 "Simulated") label(2 "Observed") ring(0) pos(2) col(1) size(medsmall) width() nobox symx(*0.5) region(lc(white)))
	**graph export "D:\MPMAS\Ghana_casestudy\TONO_01\stata/results/ValArea_barp_BSL.tif", as(tif) replace

** BAR: OBSERVED AND SIMULATED LAND USE (%)
	graph bar  p_marea p_sarea , over(cropname, gap(*0.6) sort(sarea_ws) label(angle(forty_five)) ) bar(1, fcolor(forest_green*0.7) lcolor(forest_green*0.7))  bar(2, fcolor(black) lcolor(black)) plotregion(lc(black)) graphregion(fc(white) margin(b-2 l+0)) yscale(range(0 30)) ytitle("Crop area (%)", margin(small)) bargap(0) outergap(*1) ylabel(0(10)60, glc(black*0.5) glw(*0.5) gmax gmin)  ysize(10) xsize(12) legend(label(1 "Simulated") label(2 "Observed") ring(0) pos(2) col(1) size(medsmall) width() nobox symx(*0.5) region(lc(white)))
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\stata/results/ValArea_barp_BSL.tif", as(tif) replace
gg
