* 	THIS FILE USES THE ENDDATA AND ANALYSIS THE CORRELATION BETWEEN POVERTY AND IRRIGATION


** 	CHANGE THE DIRECTORY
	cd $DIR

	

/*
**	USE ENDDATA

	use Enddata, clear

**************************************************************************

**FAMILY SIZE (IN MALE ADULT (18-62) EQUIVALENT: 3.259 BJ/YEAR)
	g hhsize = e_demand
	g hhsize_ae = hhsize / 3.259
	label var hhsize "Household size [BJ]
	label var hhsize_ae "Household size [male adult equivalents]

** PERCAPITA ENERGY CONSUMPTION

	g pcap_en = e_supply/hhsize_ae
	drop  if pcap_en==0

** PERCAPITA INCOME

	g pcap_inc = income / hhsize_ae
	drop  if pcap_inc==0

*************************************************************************************
** 	LAND USE
**************************************************************************************
** 	GROUP THE CROPS

**	RICE AREA
	egen c_irice = rowtotal(grow_irice_*)
	egen c_rfrice = rowtotal(grow_rfrice_*)
	egen c_sprice = rowtotal(grow_sprice_*)

**	RAINFED CROPS
	egen c_rfmaize = rowtotal(grow_rfmaize)
	egen c_millet = rowtotal( grow_cp_mil_1 grow_cp_mil_2 grow_cp_mil_gc_1 grow_cp_mil_gc_2 grow_cp_gc_mil_1 grow_cp_gc_mil_2 grow_millet_wocash) /*Millet and guinea corn*/
	egen c_mil_bean = rowtotal(grow_b_mb_* grow_cp_mil_b_* grow_cp_gmil_b_* grow_cp_gmil2_b_* grow_b_mb_wocash)
	egen c_gnut_bean = rowtotal(grow_b_gb grow_b_gb_m grow_b_gb_fm grow_cp_gnut_b grow_cp_gnut_b_m grow_cp_gnut_b_fm grow_cp_gnut_bb)
	egen c_groundnut = rowtotal(grow_b_gnut_* grow_cp_gnut) /*Groundnut sole crop*/

**	IRRIGATED CROP AREA
	egen c_tomato = rowtotal(grow_tom_*)
	egen c_onion = rowtotal(grow_onion_*)
	egen c_irmaize = rowtotal(grow_feb_irrimaize_* grow_mar_irrimaize_* grow_aprl_irrimaize_*)

**	TOTAL RAINFED AND IRRIGATED AREA
	gen tot_rfed = c_rfmaize + c_millet + c_mil_bean + c_gnut_bean + c_groundnut + c_rfrice
	gen tot_irri = c_irice + c_sprice +c_tomato + c_onion + c_irmaize


	save EndData_1, replace


*******************************************************************************************
*/

** PRODUCES SCATTER PLOTS OF IRRIGATED AREA AGAINST FOOD ENERGY
	** FOR 4 PERIODS WITH LINEAR REGRESSION FIT

	use EndData_1, clear

	**keep if run == "BSL"

	drop if period == 1

	g 		scenario = 0  if run == "BSL"
	replace 	scenario = 1  if run == "CRE"
	replace 	scenario = 2  if run == "FER1"
	replace  	scenario = 3  if run == "C_FER1"
	replace 	scenario = 4  if run == "FER2"
	replace 	scenario = 5  if run == "C_FER2"
	replace 	scenario = 6  if run == "BSL_DRY"
	replace 	scenario = 7  if run == "CRE_DRY"
	replace 	scenario = 8  if run == "CRE_DRYRIF"


	collapse (mean) pcap_en pcap_inc tot_irri, by(aID scenario) fast
	
	drop if scenario>=2
	
	recode scenario (0=1) (1=2), g(run)
	label define scenario 1 "Baseline" 2 "Access to credit" 
	label val run scenario


**	IRRIGATED AREA VS. ENERGY INTAKE BY DIFFERENT SCENARIOS
	graph twoway  scatter pcap_en tot_irri, msize(medsmall) mc(forest_green*2) mfc(forest_green*0.9) || lfit pcap_en tot_irri , clw(*2) clc(cranberry) by(run, legend(off) note("") col(4) graphregion(fc(white)) ) xlabel(0(0.5)2.5, labsize(large)) xtitle("Irrigated Area [Hectare]", size(medlarge) margin(medium)) ytitle("Food energy consumption [BJ/capita]", size(medlarge)) ylabel(0(5)20, angle(horizontal) labsize(large) glc(black) glw(*0.9))  ysize(7) xsize(15) plotregion(margin(zero) lc(black)) xscale(range(1.25 2.8) noline)
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\Stata\results\Scatterplot_Irri_Energy_Run.tif", replace


*/
	
gg
	recode period (2 3 4 = 1) (5 6 7 =2) (8 9 10=3)  , g(period3)
	collapse (mean) pcap_en pcap_inc tot_irri, by(aID period3 run) fast

	label define period 1 "year 2-4 " 2 "year 5-7" 3 "year 8-10" 
	label val period3 period
gg
	g l_out_lab = log10(out_lab)
	g l_out_lnd = log10(out_lnd)
	g l_yld_ima = log10(yld_ima)
*/
** 	IRRIGATED AREA VS. ENERGY INTAKE
	graph twoway  scatter pcap_en tot_irri, msize(medsmall) mc(forest_green*2) mfc(forest_green*0.9) || lfit pcap_en tot_irri , clw(*2) clc(cranberry) by(period3, legend(off) note("") col(4) graphregion(fc(white)) ) xlabel(0(0.5)3, labsize(large)) xtitle("Irrigated Area [Hectare]", size(medlarge) margin(medium)) ytitle("Food energy consumption [BJ/capita]", size(medlarge)) ylabel(0(5)25, angle(horizontal) labsize(large) glc(black) glw(*0.9))  ysize(7) xsize(15) plotregion(margin(zero) lc(black)) xscale(range(1.25 3.3) noline)
	graph export "D:\MPMAS\Ghana_casestudy\TONO_01\Stata\results\Scatterplot_Irri_Energy_period.tif", replace


** 	INCOME VS. ENERGY INTAKE
	graph twoway  scatter pcap_inc tot_irri, msize(medsmall) mc(forest_green*2) mfc(forest_green*0.9) || lfit pcap_inc tot_irri , clw(*2) clc(cranberry) by(period3, legend(off) note("") col(4) graphregion(fc(white)) ) xlabel(0(0.5)3, labsize(large)) xtitle("Irrigated Area [Hectare]", size(medlarge) margin(medium)) ytitle("Food energy consumption [BJ/capita]", size(medlarge)) ylabel(0(300)1500, angle(horizontal) labsize(large) glc(black) glw(*0.9))  ysize(7) xsize(15) plotregion(margin(zero) lc(black)) xscale(range(1.25 3.3) noline)
	graph export "D:\MPMAS\Ghana_casestudy\TONO_01\Stata\results\Scatterplot_Income_Energy_period.tif", replace



