clear
set mem 50m

set more off

*********************************************************************************

** MANUALLY SET SIM. RUN PARAMETERS / OR SET GLOBALS IN ANY OTHER FILE:

	
	** 1. SET THE MAIN DIRECTORY (THE VERSION FOLDER)
		global DIR "D:\MPMAS\TONO_206\"

	** 2. DEFINE THE PREFIX OF THE OUTPUT FILES (SIMULATION RUN):
		global RUN "BSL"


	** 3. DEFINE THE NUMBER OF CLUSTERS IN THE POPULATION:
		global CLUSTERS "4"
	

*********************************************************************************

** THE FOLLOWING PARAMETERS ARE SET AUTOMATICALLY

** A. DIRECTORY WHERE THE OUTPUT FILES ARE WRITTEN:
	global T1 "\out\"
	global OUT $DIR$T1

	cd $OUT 	/* To check whether the directory exists */

** B. DIRECTORY WHERE THE FILES WITH LABELS ARE LOCATED:
	global T2 "\Stata\labels\"
	global LAB $DIR$T2
	cd $LAB 	/* To check whether the directory exists */

** SET THE DIRECTORY WHERE THE TEMPORARY (STATA) FILES ARE TO BE WRITTEN:
	global TEMP "$DIR\MPMAS\TONO_206\Stata\temp"
	global T3 "\Stata\temp\"
	global TEMP $DIR$T3
	cd $TEMP 	/* To check whether the directory exists */

*********************************************************************************
	
** IMPORT THE ASCII FILES AND SAVE THEM IN STATA-FORMAT:

	foreach n of global RUN {
		global CLU = "0"
		local c = 0
		while `c' <= $CLUSTERS -1 {
			if `c' <  10 global CLU= "0`c'"
			if `c' >= 10 global CLU = "0`c'"
			insheet using $OUT\`n'_$CLU.lt2, tab clear
			drop in 1/6
			format v1 %10s
			destring v1, replace
			quietly g cluster	= $CLU
			quietly g str10 run = "`n'"
			quietly save "$TEMP\Scen_`n'_Clu$CLU", replace
			noisily display in green "`n'_$CLU.out" " was imported"
			local c = `c' + 1
			}
		}

** MERGE ALL FILES TOGETHER:

	foreach n of global RUN {
		global CLU = "0"
		local c = 0
		while `c' <= $CLUSTERS - 1 {
			if `c' <  10 global CLU = "0`c'"
			if `c' >= 10 global CLU = "0`c'"
			** OPEN THE FIRST FILE:
			if `c' == 0 use "$TEMP\Scen_`n'_Clu$CLU", clear
			** APPEND ALL OTHER FILES:
			if `c' >  0 append using "$TEMP\Scen_`n'_Clu$CLU"
			local c = `c' + 1
			**
			erase "$TEMP\Scen_`n'_Clu$CLU.dta"
			}
		order run cluster
		capture run $LAB\label_lt2.do
		
		* Rename and label first 7 variables:
		rename 	v1 	seed
		rename 	v2	pop
		rename 	v3	cid
		rename 	v4	vid
		rename 	v5	aid
		rename 	v6	fid
		rename 	v7	sid
		rename 	v8	plots
		replace seed = seed * -1
		label var pop "Population id
		label var cid "Cluster ID
		label var vid "Village ID
		label var aid "Agent ID
		label var fid "Farmstead ID
		label var sid "Sector ID
		label var plots "Number of plots

		drop cluster

		quietly compress
		quietly save `n'_Agents, replace
		}

** DROP THE CREATED GLOBAL MACROS:
	
	macro drop CLU TYPE LAB T* OUT 



** APPEND ALL THE AGENT POPULATION INTO A SINGLE FILE

	cd $temp
	use BSL_Agents, clear

	
	
	
	append using UER_survey_2005

	quietly save All_Agent_Populations, replace
 	drop if pop==1&aid==107
*************************************************************************************
**GENERATE VARIABLES FOR ANALYSIS

	egen hhsize=rowtotal(v9-v76)
	egen femchild=rowtotal(v9-v13)
	egen malchild=rowtotal(v43-v47)
	g childern=femchild+malchild
	g adult=hhsize-childern
	g perchildern=(femchild+malchild)/hhsize*100
	g land=plots*0.25
	egen herdsize= rowtotal(v77-v82)
	
*****************************************************************

**DEFINE VALUE LABLE 

	recode pop (0=2) (1=1), g(Typepop)
	label define pop 1 "Survey" 2 "Agent" 
	label val Typepop pop

********************************************************************

**RATIOS

**LIVESTOCK AND LAND RATIO
	
	gen livperha = herdsize/land 

	gen liveperhh = herdsize/hhsize 

gg
*****************************************************************
**GRAPHS
********************************************************************

graph twoway  scatter land hhsize, msize(medsmall) mc(forest_green*2) mfc(forest_green*0.9) || lfit land hhsize, clw(*2) clc(cranberry) by(Typepop, legend(off) note("") col(4) graphregion(fc(white)) ) xlabel(0(5)20, labsize(large)) xtitle("HH members", size(medlarge) margin(medium)) ytitle("Land (Ha)", size(medlarge)) ylabel(0(2)10, angle(horizontal) labsize(large) glc(black) glw(*0.9))  ysize(7) xsize(20) plotregion(margin(zero) lc(black)) xscale(range(1.25 4.3) noline)
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\Stata\results\Agent_hhsizeandland.tif", replace
	


	graph hbox land, over(Typepop, label(labsize(small))) over(cid, label(labsize(small))) medtype(marker) box(9, fcolor(magenta) lcolor(black) lwidth(thin)) yscale(range(0(1)10)) ytitle("Arable land in Ha") graphregion( fc(white)) plotregion(margin(zero) lc(black) ) nooutsides
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\Stata\results\Agent_survey_land.tif", replace
	

	graph hbox hhsize, over(Typepop, label(labsize(small))) over(cid, label(labsize(small))) medtype(marker) box(9, fcolor(magenta) lcolor(black) lwidth(thin)) yscale(range(0(1)10)) ytitle("Household members") graphregion( fc(white)) plotregion(margin(zero) lc(black) ) nooutsides
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\Stata\results\Agent_survey_HHsize.tif", replace
	

	drop if v78==-1
	graph hbox v78, over(Typepop, label(labsize(small))) over(cid, label(labsize(small))) medtype(marker) box(9, fcolor(magenta) lcolor(black) lwidth(thin)) yscale(range(0(1)10)) ytitle("Cows") graphregion( fc(white)) plotregion(margin(zero) lc(black) ) nooutsides
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\Stata\results\Agent_survey_cows.tif", replace


	graph hbox v79, over(Typepop, label(labsize(small))) over(cid, label(labsize(small))) medtype(marker) box(9, fcolor(magenta) lcolor(black) lwidth(thin)) yscale(range(0(1)10)) ytitle("Sheep Eve") graphregion( fc(white)) plotregion(margin(zero) lc(black) ) nooutsides
	graph export "D:\MPMAS\Ghana_casestudy\TONO_10\Stata\results\Agent_survey_sheep.tif", replace
	
