clear
set mem 500m

set more off

*********************************************************************************

** MANUALLY SET THESE PARAMETERS:


** 1. SET THE MAIN DIRECTORY (THE VERSION FOLDER)
	global Dir "G:\GHA221"

** 2. DEFINE THE PREFIX OF THE OUTPUT FILES (SIMULATION RUN):
	global RUN "T1 T2  T3 T4 T5 T6 T7 T8  T10 T11  T13 T14 T15 T16 T17 T18 T19 T20 T21 T22 T23 T24 T25  T27 T28 T29 T30  T32 T33 T34 T35 T36 T37 T38 T39  T41 T42 T43 T44 T45 T46 T47 T48 T49 T50"
	
** 3. DEFINE THE NUMBER OF PERIODS IN THE SIMULATION:
	global PERIODS "10"

** 4. DEFINE INITIAL YEAR IN THE SIMULATION
		global YEAR "2010"

** 5. DEFINE THE OUTPUT FILE TYPES TO IMPORT:
	global TYPE "k u a"
	/* AVAILABLE TYPES:
	a = agent exit data
	d = innovation diffusion data
	k = available and used resources
		v1=4 for available capacity (resources)
		v1=5 for actually used capacity
	p = agent performance data
	u = solution vector 
		v1=2 for primal solution 
		v1=3 for objective values
	y = crop yield data
	w = sector water data
	l = land data
	*/

*********************************************************************************

** THE FOLLOWING PARAMETERS ARE SET AUTOMATICALLY

** A. DIRECTORY WHERE THE OUTPUT FILES ARE WRITTEN:
	global T1 "\out\"
	global OUT $Dir$T1
	cd $OUT 	/* To check whether the directory exists */

** B. DIRECTORY WHERE THE FILES WITH LABELS ARE LOCATED:
	global T2 "\Stata\labels\"
	global LAB $Dir$T2
	cd $LAB 	/* To check whether the directory exists */

** SET THE DIRECTORY WHERE THE TEMPORARY (STATA) FILES ARE TO BE WRITTEN:
	global TEMP "$dir\G:\GHA221\Stata\temp"
	global T3 "\Stata\temp\"
	global TEMP $Dir$T3
	cd $TEMP 	/* To check whether the directory exists */

*********************************************************************************


** IMPORT THE ASCII FILES AND SAVE THEM IN STATA-FORMAT:

	foreach n of global RUN {
		foreach t of global TYPE {
			global PER = "0"
			local p = 1
			while `p' <= $PERIODS {
				if `p' <  10 global PER = "0`p'"
				if `p' >= 10 global PER = "`p'"
				quietly insheet using $OUT\`n'_`t'$PER.out, tab clear nonames
				quietly g 		period	= $PER
				quietly g str10	run		= "`n'"
				quietly save "$TEMP\temp_`n'_`t'$PER", replace
				noisily display in green "`n'_`t'$PER.out" " was imported"
				local p = `p' + 1
				}
			}
		}


** MERGE ALL FILES TOGETHER:

	foreach n of global RUN {
		foreach t of global TYPE {
			global PER = "0"
			local p = 1
			while `p' <= $PERIODS {
				if `p' <  10 global PER = "0`p'"
				if `p' >= 10 global PER = "`p'"
				** OPEN THE FIRST FILE:
				if `p' == 1 	   use "$TEMP\temp_`n'_`t'$PER", clear
				** APPEND ALL OTHER FILES:
				if `p' >  1 append using "$TEMP\temp_`n'_`t'$PER"
				local p = `p' + 1
				**
				erase "$TEMP\temp_`n'_`t'$PER.dta"
				}


			order run period

			capture run "$LAB\label_`t'.do"

			quietly compress
			if "`t'" == "u" {
				quietly save "temp_`t'.dta", replace
				quietly keep if typ_str == 2
				sort run period popID aID 
				quietly save "$TEMP\`n'_Solution.dta", replace
				quietly use "temp_`t'.dta", clear
				quietly keep if typ_str == 3
				sort run period popID aID 
				quietly save "$TEMP\`n'_Prices.dta", replace
				erase "temp_`t'.dta"
				}
			else if "`t'" == "k" {
				quietly save "temp_`t'.dta", replace
				quietly keep if typ_str  == 4
				sort run period popID aID 
				quietly save "$TEMP\`n'_Rhs.dta", replace
				quietly use "temp_`t'.dta", clear
				quietly keep if typ_str  == 5
				sort run period popID aID 
				quietly save "$TEMP\`n'_Lhs.dta", replace
				erase "temp_`t'.dta"
				}
			

				else if "`t'" == "p" {
				capture run "$LAB\label_p.do"
				quietly save "temp_`t'.dta", replace
				quietly use "temp_`t'.dta", clear
				sort run period popID aID  
				quietly save "$TEMP\`n'_Performance.dta", replace
				erase "temp_`t'.dta"
				}

		else {
				quietly save "$TEMP\`n'_`t'.dta", replace
				}			
		}
			}	

** DROP THE CREATED GLOBAL MACROS:
	
	macro drop RUN PERIODS PER TYPE LAB


